@@ -1,10 +1,10 @@
 use 5.014;
-#package Thread::Queue::Any::Monitored '1.02'; # not at PAUSE or MetaCPAN :-(
+#package Thread::Queue::Any::Monitored '1.03'; # not at PAUSE or MetaCPAN :-(
 package Thread::Queue::Any::Monitored;  # please remove if no longer needed
 
 # initializations
 our @ISA= qw( Thread::Queue::Any );
-our $VERSION= '1.02';                   # please remove if no longer needed
+our $VERSION= '1.03';                   # please remove if no longer needed
 
 # be as verbose as possible
 use warnings;
@@ -135,7 +135,7 @@ Thread::Queue::Any::Monitored - monitor a queue for any specific content
 
 =head1 VERSION
 
-This documentation describes version 1.02.
+This documentation describes version 1.03.
 
 =head1 DESCRIPTION
 
@@ -317,8 +317,8 @@ for a description of the options for using specific data serializers.
 =head1 REQUIRED MODULES
 
  Test::More (0.88)
- Thread::Queue::Any (1.11)
- Thread::Queue::Monitored (1.02)
+ Thread::Queue::Any (1.13)
+ Thread::Queue::Monitored (1.04)
 
 =head1 INSTALLATION
 
@@ -347,6 +347,9 @@ systems like so:
 If your perl does not support the "blead" version of the code, then it will
 automatically install the "maint" version of the code.
 
+Please note that any additional parameters will simply be passed on to the
+underlying Makefile.PL processing.
+
 =head1 CAVEATS
 
 You cannot remove any values from the queue, as that is done by the monitoring
